Autosubmit Statistics — autosubmit 3.9.1 documentation

# Autosubmit Statistics

When you click on the `Statistics` tab, you will see two input boxes: `Section` and `Hours`, followed by the button `Get Statistics`:

49 Experiment Statistics

There is also a brief explanation of the input fields and expected result. Basically, `Section` allows you to narrow your search to certain job types, and `Hours` allows you to set a time limit to look into the past in hours.

In this example we have queried 3 hours into the past:

50 Experiment Statistics (Last 3 hours)

Click on the button `Clear Statistics` to clear the results and submit another query.

Important

For more details about Autosubmit statistics, refer to: How to monitor job statistics.